#ifndef __KWLANAPPLICATION__ 
#define __KWLANAPPLICATION__ 
/** KWlan
 *
 *  This File is part of KWlan, a network Manager for KDE.
 *  KWlan is distributed under LGPL license.
 *
 *	@author Thomas Michel <tom.michel@arcor.de>
 */

#include <kuniqueapplication.h>

class KProcess;
class QString;
class KDialup;

class KWlanApplication : public KUniqueApplication
{
    Q_OBJECT
    public: 
        KWlanApplication(bool allowStyles=true, bool GUIenabled=true, bool configUnique=false);
        ~KWlanApplication();
        void init();
    private:
        QString m_ifconfigStdout;

    
};
#endif
